==> tellico_3.1.orig.tar.xz: tellico-3.1/src/tests/imagetest.cpp <==
/***************************************************************************
    Copyright (C) 2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#undef QT_NO_CAST_FROM_ASCII

#include "imagetest.h"

#include "../images/imagefactory.h"

#include <QTest>

QTEST_GUILESS_MAIN( ImageTest )

void ImageTest::initTestCase() {
  Tellico::ImageFactory::init();
}

void ImageTest::testLinkOnly() {
  QUrl u = QUrl::fromLocalFile(QFINDTESTDATA("../../icons/hi128-app-tellico.png"));
  // addImage(url, quiet, referer, link)
  QString id = Tellico::ImageFactory::addImage(u, false, QUrl(), true);
  QCOMPARE(id, u.url());
}

==> tellico_3.4.6.orig.tar.xz: tellico-3.4.6/src/tests/imagetest.cpp <==
/***************************************************************************
    Copyright (C) 2009-2021 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#include "imagetest.h"

#include "../images/imagefactory.h"
#include "../images/image.h"

#include <QTest>
#include <QStandardPaths>

QTEST_GUILESS_MAIN( ImageTest )

void ImageTest::initTestCase() {
  QStandardPaths::setTestModeEnabled(true);
  Tellico::ImageFactory::init();
}

void ImageTest::testLinkOnly() {
  QUrl u = QUrl::fromLocalFile(QFINDTESTDATA("../../icons/128-apps-tellico.png"));
  // addImage(url, quiet, referer, link)
  QString id = Tellico::ImageFactory::addImage(u, false, QUrl(), true);
  QCOMPARE(id, u.url());
}

void ImageTest::testOrientation() {
  QUrl u1 = QUrl::fromLocalFile(QFINDTESTDATA("data/img1.jpg"));
  QString id1 = Tellico::ImageFactory::addImage(u1);
  const Tellico::Data::Image& img1 = Tellico::ImageFactory::imageById(id1);
  QRgb px = img1.pixel(0, 0);
  QVERIFY(qRed(px) > 250 && qGreen(px) < 5 && qBlue(px) < 5);

  QUrl u2 = QUrl::fromLocalFile(QFINDTESTDATA("data/img2.jpg"));
  QString id2 = Tellico::ImageFactory::addImage(u2);
  const Tellico::Data::Image& img2 = Tellico::ImageFactory::imageById(id2);
  px = img2.pixel(0, 0);
  QVERIFY(qRed(px) > 250 && qGreen(px) < 5 && qBlue(px) < 5);
}
